@@ -13,6 +13,7 @@
 #include <ctype.h>
 #include <assert.h>
 #include <getopt.h>
+#include <libgen.h>
 
 #if HAVE_LIBPNG
 # include <png.h>
@@ -685,6 +686,11 @@ static void explain (void) {
 	  print_command ("Undocumented command");
 	  break;
 
+	case 'c':  /* ESC i c */
+	  d = get_more (DATA, 5);
+	  print_command ("Legacy hires");
+	  break;
+
 	default:
 	  unknown_command ();
 	  break;
